# RemoveCookiesNotice

This library is aimed at removing cookies notices in scraped web pages

It do so using two strategies : 
* By using known attributes values
* By fuzzy matching text in HTML page

This is very much a work in progress
